@@ -5,26 +5,20 @@
 import json
 
 from jsonschema import ValidationError
-from jupyter_server.extension.handler import (
-    ExtensionHandlerJinjaMixin,
-    ExtensionHandlerMixin,
-)
+from jupyter_server.extension.handler import ExtensionHandlerJinjaMixin, ExtensionHandlerMixin
 from tornado import web
 
 from .settings_utils import SchemaHandler, get_settings, save_settings
-from .translation_utils import DEFAULT_LOCALE, translator
+from .translation_utils import translator
 
 
 class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, SchemaHandler):
+    """A settings API handler."""
+
     def initialize(
-        self,
-        name,
-        app_settings_dir,
-        schemas_dir,
-        settings_dir,
-        labextensions_path,
-        **kwargs
+        self, name, app_settings_dir, schemas_dir, settings_dir, labextensions_path, **kwargs
     ):
+        """Initialize the handler."""
         SchemaHandler.initialize(
             self, app_settings_dir, schemas_dir, settings_dir, labextensions_path
         )
@@ -32,18 +26,25 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, SchemaH
 
     @web.authenticated
     def get(self, schema_name=""):
-        """Get setting(s)"""
+        """
+        Get setting(s)
+
+        Parameters
+        ----------
+        schema_name: str
+            The id of a unique schema to send, added to the URL
+
+        ## NOTES:
+            An optional argument `ids_only=true` can be provided in the URL to get only the
+            ids of the schemas instead of the content.
+        """
         # Need to be update here as translator locale is not change when a new locale is put
         # from frontend
-        try:
-            locale = self.get_current_locale()
-        except web.HTTPError as e:
-            # fallback in case of missing (404) or misshapen (500) translation schema
-            locale = DEFAULT_LOCALE
-            'Failed loading or validating translation settings schema'
-
+        locale = self.get_current_locale()
         translator.set_locale(locale)
 
+        ids_only = self.get_argument('ids_only', '') == 'true'
+
         result, warnings = get_settings(
             self.app_settings_dir,
             self.schemas_dir,
@@ -51,13 +52,14 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, SchemaH
             labextensions_path=self.labextensions_path,
             schema_name=schema_name,
             overrides=self.overrides,
-            translator=translator.translate_schema
+            translator=translator.translate_schema,
+            ids_only=ids_only,
         )
 
         # Print all warnings.
         for w in warnings:
             if w:
-                self.log.warn(w)
+                self.log.warning(w)
 
         return self.finish(json.dumps(result))
 
@@ -67,15 +69,17 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, SchemaH
         overrides = self.overrides
         schemas_dir = self.schemas_dir
         settings_dir = self.settings_dir
-        settings_error = 'No current settings directory'
-        invalid_json_error = 'Failed parsing JSON payload: %s'
-        invalid_payload_format_error = 'Invalid format for JSON payload. Must be in the form {\'raw\': ...}'
-        validation_error = 'Failed validating input: %s'
+        settings_error = "No current settings directory"
+        invalid_json_error = "Failed parsing JSON payload: %s"
+        invalid_payload_format_error = (
+            "Invalid format for JSON payload. Must be in the form {'raw': ...}"
+        )
+        validation_error = "Failed validating input: %s"
 
         if not settings_dir:
             raise web.HTTPError(500, settings_error)
 
-        raw_payload = self.request.body.strip().decode('utf-8')
+        raw_payload = self.request.body.strip().decode("utf-8")
         try:
             raw_settings = json.loads(raw_payload)["raw"]
             save_settings(
@@ -87,10 +91,10 @@ class SettingsHandler(ExtensionHandlerMixin, ExtensionHandlerJinjaMixin, SchemaH
                 self.labextensions_path,
             )
         except json.decoder.JSONDecodeError as e:
-            raise web.HTTPError(400, invalid_json_error % str(e))
-        except (KeyError, TypeError) as e:
-            raise web.HTTPError(400, invalid_payload_format_error)
+            raise web.HTTPError(400, invalid_json_error % str(e)) from None
+        except (KeyError, TypeError):
+            raise web.HTTPError(400, invalid_payload_format_error) from None
         except ValidationError as e:
-            raise web.HTTPError(400, validation_error % str(e))
+            raise web.HTTPError(400, validation_error % str(e)) from None
 
         self.set_status(204)
